==> lxqt-panel_1.4.0.orig.tar.xz: lxqt-panel-1.4.0/plugin-quicklaunch/translations/quicklaunch_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="227"/>
        <source>Drop Error</source>
        <translation>Vilkimo klaida</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="228"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Failas/URL &quot;%1&quot; dabar negali būti įtaisytas į spartųjį paleidimą</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="334"/>
        <source>Drop application
icons here</source>
        <translation>Vilkite programų
piktogramas čia</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + DND)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Perkelti kairėn</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Perkelti dešinėn</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Šalinti iš sparčiojo paleidimo</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation>Įkelti iš naujo</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.0.0.tar.xz: lxqt-panel-2.0.0/plugin-quicklaunch/translations/quicklaunch_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="227"/>
        <source>Drop Error</source>
        <translation>Vilkimo klaida</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="228"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Failas/URL „%1“ dabar negali būti įtaisytas į spartųjį paleidimą</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="334"/>
        <source>Drop application
icons here</source>
        <translation>Vilkite programų
piktogramas čia</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + DND)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Perkelti kairėn</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Perkelti dešinėn</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Šalinti iš sparčiojo paleidimo</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation>Įkelti iš naujo</translation>
    </message>
</context>
</TS>
